.. _modules-node_builder:

##############
 Node builder
##############

.. automodule:: anemoi.graphs.nodes.builders.from_file
   :members:
   :no-undoc-members:
   :show-inheritance:

.. automodule:: anemoi.graphs.nodes.builders.from_icon
   :members:
   :no-undoc-members:
   :exclude-members: ICONTopologicalBaseEdgeBuilder
   :show-inheritance:

.. automodule:: anemoi.graphs.nodes.builders.from_healpix
   :members:
   :no-undoc-members:
   :show-inheritance:

.. automodule:: anemoi.graphs.nodes.builders.from_refined_icosahedron
   :members:
   :exclude-members: IcosahedralNodes,LimitedAreaIcosahedralNodes,StretchedIcosahedronNodes
   :no-undoc-members:
   :show-inheritance:
